embassy-stm32

Crates

git

Versions

stm32h7r7l8

Flavors

CompVals

Struct CompVals 

pub struct CompVals {
    pub octo1_nsrc: u8,
    pub octo1_psrc: u8,
    pub octo2_nsrc: u8,
    pub octo2_psrc: u8,
    pub io_nsrc: u8,
    pub io_psrc: u8,
}
Compensation cell calibration values. The N-MOS and P-MOS transistors slew rate compensation factors are stored for the three different compensation cells available in the STM32H7RS family.

Fields

octo1_nsrc: u8

XSPI1 N-MOS transistors slew-rate compensation value [0-15].

octo1_psrc: u8

XSPI1 P-MOS transistors slew-rate compensation value [0-15].

octo2_nsrc: u8

XSPI2 N-MOS transistors slew-rate compensation value [0-15].

octo2_psrc: u8

XSPI2 P-MOS transistors slew-rate compensation value [0-15].

io_nsrc: u8

GPIO N-MOS transistors slew-rate compensation value [0-15].

io_psrc: u8

GPIO P-MOS transistors slew-rate compensation value [0-15].