#[non_exhaustive]pub struct Config {Show 24 fields
pub hsi: Option<HSIPrescaler>,
pub hse: Option<Hse>,
pub csi: bool,
pub hsi48: Option<Hsi48Config>,
pub sys: Sysclk,
pub pll1: Option<Pll>,
pub pll2: Option<Pll>,
pub pll3: Option<Pll>,
pub d1c_pre: AHBPrescaler,
pub ahb_pre: AHBPrescaler,
pub apb1_pre: APBPrescaler,
pub apb2_pre: APBPrescaler,
pub apb4_pre: APBPrescaler,
pub apb5_pre: APBPrescaler,
pub timer_prescaler: TimerPrescaler,
pub voltage_scale: VoltageScale,
pub ls: LsConfig,
pub supply_config: SupplyConfig,
pub mux: ClockMux,
pub hslv_xspi1: bool,
pub hslv_xspi2: bool,
pub hslv_io: bool,
pub comp_xspi1: bool,
pub comp_xspi2: bool,
}Expand description
Configuration of the core clocks
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hsi: Option<HSIPrescaler>hse: Option<Hse>csi: boolhsi48: Option<Hsi48Config>sys: Sysclkpll1: Option<Pll>pll2: Option<Pll>pll3: Option<Pll>d1c_pre: AHBPrescalerahb_pre: AHBPrescalerapb1_pre: APBPrescalerapb2_pre: APBPrescalerapb4_pre: APBPrescalerapb5_pre: APBPrescalertimer_prescaler: TimerPrescalervoltage_scale: VoltageScalels: LsConfigsupply_config: SupplyConfigmux: ClockMuxPer-peripheral kernel clock selection muxes
hslv_xspi1: boolEnable HSLV mode for XSPI1. CAUTION: enabling when VDD_XSPI1 > 2.7 V may be destructive!
hslv_xspi2: boolEnable HSLV mode for XSPI2. CAUTION: enabling when VDD_XSPI2 > 2.7 V may be destructive!
hslv_io: boolEnable HSLV mode for I/O pins. CAUTION: enabling when VDD > 2.7 V may be destructive!
comp_xspi1: boolEnable the compensation cell for XSPI1. Enabling with no active device connected will fail with time-out.
comp_xspi2: boolEnable the compensation cell for XSPI2. Enabling with no active device connected will fail with time-out.
Implementations